<?php

namespace Drupal\image_style_desc\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Image Style Description module.
 */
class ImageStyleDescSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['image_style_desc.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'image_style_desc_settings_form';
  }

  /**
   * Build the configuration form.
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('image_style_desc.settings');
    $content_types = \Drupal::service('entity_type.manager')
      ->getStorage('node_type')
      ->loadMultiple();

    $form['excluded_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Exclude content types'),
      '#description' => $this->t('Select the content types where the image style description should be excluded.'),
      '#options' => array_map(fn($type) => $type->label(), $content_types),
      '#default_value' => $config->get('excluded_content_types') ?? [],
    ];

    $form['image_style_desc'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Image Style Description'),
      '#description' => $this->t('Enter the description template for the image. Use @style for the style name and @dimensions for the dimensions.'),
      '#default_value' => $config->get('image_style_desc') ?: $this->t('The standard dimensions for the @style image style are @dimensions.'),
    ];
    $form['all_view_modes'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Apply to all view modes'),
      '#description' => $this->t('Apply the description to all view modes.'),
      '#default_value' => $config->get('all_view_modes') ?? FALSE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('image_style_desc.settings')
      ->set('excluded_content_types', array_filter($form_state->getValue('excluded_content_types')))
      ->set('image_style_desc', $form_state->getValue('image_style_desc'))
      ->set('all_view_modes', $form_state->getValue('all_view_modes'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
